@@ -4,12 +4,12 @@
 
 export DISPLAY=:0.0
 
-liqbase-cpu-performance
+liqbase-playground-cpu-performance
 
 cd /usr/share/liqbase
 
 ./liqbase-playground -showwidget kotcomix,tagcloud,liqcontrolpanel,liqcalendar,ciroclock_minutes,liqtop,liqrecentsketches,liqrecentusers,liqbook
 
-liqbase-cpu-ondemand
+liqbase-playground-cpu-ondemand
 
 
